@@ -7,7 +7,7 @@ use warnings 'all';
 ###########################################################################
 # METADATA
 our $AUTHORITY = 'cpan:DOUGDUDE';
-our $VERSION   = '0.003';
+our $VERSION   = '0.004';
 
 ###########################################################################
 # MODULE IMPORTS
@@ -263,8 +263,16 @@ sub _register_handler {
 	my ($self, $handler, %args) = @_;
 
 	# Add m_ to the beginning of the arguments
-	foreach my $key (keys %args) {
-		if ($key !~ m{\A m_}msx) {
+	for my $key (keys %args) {
+		# Specially handle "url" key as HTTP::Config does not
+		if ($key eq 'url' || $key eq 'uri') {
+			# Get the URI from the arguments
+			my $uri = URI->new(delete $args{$key});
+
+			# Set a match against it's canonical value
+			$args{m_uri__canonical} = $uri->canonical;
+		}
+		elsif (q{m_} ne substr $key, 0, 2) {
 			# Add m_
 			$args{"m_$key"} = delete $args{$key};
 		}
@@ -360,10 +368,11 @@ sub _new_internal_response {
 	my $response = HTTP::Response->new($code, $message);
 
 	# Set some headers for client information
-	$response->headers(
-		'Client-Date'    => HTTP::Date::time2str(time),
-		'Client-Warning' => 'Internal response',
-		'Content-Type'   => 'text/plain',
+	$response->header(
+		'Client-Date'            => HTTP::Date::time2str(time),
+		'Client-Response-Source' => __PACKAGE__,
+		'Client-Warning'         => 'Internal response',
+		'Content-Type'           => 'text/plain',
 	);
 
 	# Set the content as the status_line
@@ -448,7 +457,7 @@ Test::Override::UserAgent - Override the LWP::UserAgent to return canned respons
 
 =head1 VERSION
 
-Version 0.003
+Version 0.004
 
 =head1 SYNOPSIS
 
@@ -622,7 +631,22 @@ is C<0> to not clone the user agent.
 This will add a new request override to the configuration. The argument is a
 plain hash with the keys that L<HTTP::Config|HTTP::Config> takes as specified in
 L<HTTP::Config/Matching>. The keys may leave off the C<m_> prefix. The
-subroutine must function as specified in L</HANDLER SUBROUTINE>.
+subroutine must function as specified in L</HANDLER SUBROUTINE>. Some
+short-hands are provided as follows:
+
+=over 4
+
+=item C<uri> or C<url>
+
+B<Added in version 0.004>; be sure to require this version for this feature.
+
+These are not supported directly by L<HTTP::Config|HTTP::Config> but will be
+translated to a L<HTTP::Config|HTTP::Config>-compatible syntax for you. This
+allows you to do the following:
+
+  $config->override_request(url => 'http://exmaple.org/search', \&search_handler);
+
+=back
 
 =head2 uninstall_from_user_agent
 
@@ -652,6 +676,28 @@ status code of 417 will be returned.
 
 =back
 
+=head1 DIAGNOSTIC HEADERS
+
+When a request was stopped or an error was encountered within the
+request-handling procedures of this module, there are some extra headers
+added to the response object. These include the standard diagnostic headers
+that L<LWP::UserAgent|LWP::UserAgent> will add, with one additional header.
+
+=head2 C<Client-Date>
+
+This is the current date and time the response was generated by the client.
+
+=head2 C<Client-Warning>
+
+Just like with L<LWP::UserAgent|LWP::UserAgent> this will be C<"Internal response">.
+
+=head2 C<Client-Response-Source>
+
+This header is unique to this module, and will indicate the source module
+that generated the response. Typically this will always be C<"Test::Override::UserAgent">.
+This provides additional information to determine that the response was generated
+by this module instead of by the L<LWP::UserAgent|LWP::UserAgent> family of modules.
+
 =head1 DEPENDENCIES
 
 =over 4
